Hanna - Anna for HOCON
======================

Inspired by `anna <https://pypi.org/project/anna/>`__ -- revised and refurbished,
uses `HOCON <https://github.com/lightbend/config/blob/master/HOCON.md>`__
via `pyhocon <https://pypi.org/project/pyhocon/>`__.

This project applies *Documentation Driven Development*.

Implemented features are described
`here <https://gitlab.com/Dominik1123/Hanna/issues?scope=all&utf8=%E2%9C%93&state=closed&label_name[]=feature>`__
while features that are still pending can be found
`here <https://gitlab.com/Dominik1123/Hanna/issues?scope=all&utf8=%E2%9C%93&state=opened&label_name[]=feature>`__.
For a description of all features please visit
`this page <https://gitlab.com/Dominik1123/Hanna/issues?scope=all&utf8=%E2%9C%93&state=all&label_name[]=feature>`__.
These resources basically comprise the documentation of the project (for now).
